package com.inspect.exec.mapper;

import com.inspect.exec.domain.PatrolTaskExecRecord;

import java.util.List;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

@Mapper
public interface PatrolTaskExecRecordMapper {
    PatrolTaskExecRecord selectPatrolTaskExecRecordByTaskPatrolId(String patrolId);

    List<PatrolTaskExecRecord> selectPatrolTaskExecRecordList(PatrolTaskExecRecord record);

    int insertPatrolTaskExecRecord(PatrolTaskExecRecord record);

    int updatePatrolTaskExecRecord(PatrolTaskExecRecord record);

    int deletePatrolTaskExecRecordByTaskPatrolId(String patrolId);

    int deletePatrolTaskExecRecordByTaskPatrolIds(String[] patrolIds);

    List<PatrolTaskExecRecord> selectCameraPatrolTaskExecRecordList(@Param("taskCode") String taskCode, @Param("devNo") String devNo, @Param("taskStates") List<String> taskStates);

    List<PatrolTaskExecRecord> selectAbeyancePatrolTaskExecRecordList(PatrolTaskExecRecord var1);

    int deletePatrolTaskExecRecordByTaskState(String var1);
}
